[![Build Status](https://cd.screwdriver.cd/pipelines/2835/badge)](https://cd.screwdriver.cd/pipelines/2835)
[![Documentation](https://readthedocs.org/projects/invirtualenv/badge/?version=latest)](https://invirtualenv.readthedocs.io/en/latest/?badge=latest)
[![Code Coverage](https://codecov.io/gh/yahoo/invirtualenv/branch/master/graph/badge.svg)](https://codecov.io/gh/yahoo/invirtualenv)
[![Wheel](https://img.shields.io/pypi/wheel/invirtualenv.svg)](https://pypi.org/project/invirtualenv/)
[![Downloads](https://pepy.tech/badge/invirtualenv)](https://pepy.tech/project/invirtualenv)

# InVirtualEnv

Utilities for deploying applications written in Python.


## Background

This project is an extensible utility that creates deployment artifacts for Python applications in multiple formats from a single configuration file.  This simplifies the creation of CI Pipelines that support multiple installation methods.

## Contribute

Please refer to [the contributing.md file](Contributing.md) for information about how to get involved. We welcome issues, questions, and pull requests. Pull Requests are welcome.

## License

This project is licensed under the terms o fthe [BSD](LICENSE-BSD) open source license.  Please refer to [LICENSE](LICENSE.txt) for the full terms.
